@@ -114,15 +114,13 @@ class DynamicAnnotationDB:
 
     def get_table_row_count(self, table_name: str, filter_valid: bool = False) -> int:
         model = self.cached_table(table_name)
+        query = self.cached_session.query(func.count(model.id))
         if filter_valid:
-            row_count = (
-                self.cached_session.query(func.count(model.id))
-                .filter(model.valid is True)
-                .scalar()
+            query = self.cached_session.query(func.count(model.id)).filter(
+                model.valid == True
             )
-        else:
-            row_count = self.cached_session.query(func.count(model.id)).scalar()
-        return row_count
+
+        return query.scalar()
 
     @staticmethod
     def get_automap_items(result):
@@ -159,7 +157,7 @@ class DynamicAnnotationDB:
             )
         return existing_tables
 
-    def _get_existing_table_names(self) -> List[str]:
+    def _get_existing_table_names(self, filter_valid: bool = False) -> List[str]:
         """Collects table_names keys of existing tables
 
         Returns
@@ -167,7 +165,10 @@ class DynamicAnnotationDB:
         list
             List of table_names
         """
-        metadata = self.cached_session.query(AnnoMetadata).all()
+        stmt = self.cached_session.query(AnnoMetadata)
+        if filter_valid:
+            stmt = stmt.filter(AnnoMetadata.valid == True)
+        metadata = stmt.all()
         return [m.table_name for m in metadata]
 
     def _get_model_from_table_name(self, table_name: str) -> DeclarativeMeta:
@@ -235,8 +236,7 @@ class DynamicAnnotationDB:
             )
             return True
         except KeyError as key_error:
-            if table_name in self._get_existing_table_names():
-                logging.error(f"Could not load table: {key_error}")
+            logging.error(f"Could not load table: {key_error}")
             return False
 
     def _is_cached(self, table_name: str) -> bool:
